package earth.krakatoa.mongo;

import com.mongodb.ConnectionString;
import com.mongodb.MongoClientSettings;
import com.mongodb.ServerApi;
import com.mongodb.ServerApiVersion;
import com.mongodb.reactivestreams.client.MongoClient;
import com.mongodb.reactivestreams.client.MongoClients;
import earth.krakatoa.config.MongoConfig;
import lombok.Data;

@Data
public class MongoManager {

  private ConnectionString connectionString;

  private ServerApi serverApi;
  private MongoClientSettings mongoClientSettings;
  private MongoClient mongoClient;

  public void connect(MongoConfig mongoConfig) {
    this.connectionString = new ConnectionString(
        "mongodb://" + mongoConfig.getUsername() + ":" + mongoConfig.getPassword() + "@"
            + mongoConfig.getHostname() + ":" + mongoConfig.getPort() + "/?authSource="
            + mongoConfig.getDatabase()
            + "&readPreference=primary&ssl=false");

    this.serverApi = ServerApi.builder().version(ServerApiVersion.V1).build();

    this.mongoClientSettings = MongoClientSettings.builder()
        .applyConnectionString(this.connectionString).serverApi(this.serverApi).build();

    this.mongoClient = MongoClients.create(this.mongoClientSettings);
  }

  public void shutdown() {
    this.mongoClient.close();
  }
}
